@@ -41,5 +41,5 @@ def CaptureJob():
     cwd = os.getcwd()
     
     folder = f"{date_time}_{job}"
-    fileservice.upload(os.path.join(cwd,"stdout.txt"),folder,"stdout.txt")    
+    fileservice.upload(os.path.join(cwd,"log.txt"),folder,"log.txt")    
  
\ No newline at end of file
